@@ -112,7 +112,10 @@ def run_command_set(
         )
         outcomes.append(current_outcome)
         try:
-            current_outcome.assert_success()
+            if cmd.invert_exit_code:
+                current_outcome.assert_failure()
+            else:
+                current_outcome.assert_success()
         except SystemExit as exception:
             if cmd.ignore_exit_code:
                 logging.warning("command failed but is marked ignore outcome so handling it as success")
